**Usage**

|PythonVersion|_ |License|_ |PoweredBy|_

**Development**

|Pep8|_

**Release**

|PyPi|_


.. |PythonVersion| image:: https://img.shields.io/badge/python-3.6%20%7C%203.7%20%7C%203.8%20%7C%203.9-blue
.. _PythonVersion: https://img.shields.io/badge/python-3.6%20%7C%203.7%20%7C%203.8%20%7C%203.9-blue

.. |Pep8| image:: https://github.com/rlink7/rlink_7limri/actions/workflows/pep8.yml/badge.svg
.. _Pep8: https://github.com/rlink7/rlink_7limri/actions

.. |PyPi| image:: https://badge.fury.io/py/limri.svg
.. _PyPi: https://badge.fury.io/py/limri

.. |License| image:: https://img.shields.io/badge/License-CeCILLB-blue.svg
.. _License: http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html

.. |PoweredBy| image:: https://img.shields.io/badge/Powered%20by-CEA%2FNeuroSpin-blue.svg
.. _PoweredBy: https://joliot.cea.fr/drf/joliot/Pages/Entites_de_recherche/NeuroSpin.aspx


limri: tools to pre-process Lithium imaging
===========================================

\:+1: If you are using the code please add a star to the repository :+1:

This module has been created to do some pre-processings on Lithium MRI.
You can list all available workflows by running the following command in a
command prompt:

.. code::

    limri --help


Important links
===============

* Official source code repo: https://github.com/rlink7/rlink_7limri
* HTML documentation (stable release): WIP
* HTML documentation (latest release): WIP
* Release notes: https://github.com/rlink7/rlink_7limri/blob/master/CHANGELOG.rst


Dependencies
============

`limri` requires the installation of the following system packages:

* Python [>=3.6]


Install
=======

First make sure you have installed all the dependencies listed above.
Then you can install `limri` by running the following command in a
command prompt:

.. code::

    pip install -U --user limri


Contributing
============

If you want to contribute to `limri`, be sure to review the `contribution guidelines`_.

.. _contribution guidelines: ./CONTRIBUTING.rst


Citation
========

There is no paper published yet about `limri`.
We suggest that you aknowledge the brainprep team or reference to the code
repository: |link-to-paper|. Thank you.

.. |link-to-paper| raw:: html

      <a href="https://github.com/rlink7/rlink_7limri "target="_blank">
      Grigis, A. et al. (2022) BrainPrep source code (Version 0.01) [Source code].
      https://github.com/rlink7/rlink_7limri </a>
